summaryrefslogtreecommitdiffstats
path: root/src/generated
diff options
context:
space:
mode:
authorCyborus <cyborus@cyborus.xyz>2024-05-14 17:36:44 +0200
committerCyborus <cyborus@cyborus.xyz>2024-05-14 17:36:44 +0200
commited310f70015cc2a9d634aca6a8787b9a865fe0eb (patch)
tree3688f8808ce0f03dc2e2d90f5befab605a8fb88c /src/generated
parentMerge pull request 'feat: implement ssh_url deserialization to `url::Url` ins... (diff)
downloadforgejo-api-ed310f70015cc2a9d634aca6a8787b9a865fe0eb.tar.xz
forgejo-api-ed310f70015cc2a9d634aca6a8787b9a865fe0eb.zip
make issue and pr state an enum
Diffstat (limited to 'src/generated')
-rw-r--r--src/generated/structs.rs17
1 files changed, 11 insertions, 6 deletions
diff --git a/src/generated/structs.rs b/src/generated/structs.rs
index e727b5d..f7b8ce8 100644
--- a/src/generated/structs.rs
+++ b/src/generated/structs.rs
@@ -1445,7 +1445,7 @@ pub struct Issue {
#[serde(rename = "ref")]
pub r#ref: Option<String>,
pub repository: Option<RepositoryMeta>,
- pub state: Option<String>,
+ pub state: Option<StateType>,
pub title: Option<String>,
#[serde(with = "time::serde::rfc3339::option")]
pub updated_at: Option<time::OffsetDateTime>,
@@ -1738,7 +1738,7 @@ pub struct Milestone {
pub due_on: Option<time::OffsetDateTime>,
pub id: Option<u64>,
pub open_issues: Option<u64>,
- pub state: Option<String>,
+ pub state: Option<StateType>,
pub title: Option<String>,
#[serde(with = "time::serde::rfc3339::option")]
pub updated_at: Option<time::OffsetDateTime>,
@@ -1822,7 +1822,7 @@ pub struct NotificationSubject {
pub latest_comment_html_url: Option<url::Url>,
#[serde(deserialize_with = "crate::none_if_blank_url")]
pub latest_comment_url: Option<url::Url>,
- pub state: Option<String>,
+ pub state: Option<StateType>,
pub title: Option<String>,
#[serde(rename = "type")]
pub r#type: Option<String>,
@@ -2035,7 +2035,7 @@ pub struct PullRequest {
pub patch_url: Option<url::Url>,
pub pin_order: Option<u64>,
pub requested_reviewers: Option<Vec<User>>,
- pub state: Option<String>,
+ pub state: Option<StateType>,
pub title: Option<String>,
#[serde(with = "time::serde::rfc3339::option")]
pub updated_at: Option<time::OffsetDateTime>,
@@ -2327,9 +2327,14 @@ pub struct ServerVersion {
}
/// StateType issue state type
-#[derive(Debug, Clone, PartialEq, serde::Serialize, serde::Deserialize)]
-pub struct StateType {}
+#[derive(Debug, Clone, Copy, PartialEq, Eq, serde::Serialize, serde::Deserialize)]
+pub enum StateType {
+ #[serde(rename = "open")]
+ Open,
+ #[serde(rename = "closed")]
+ Closed,
+}
/// StopWatch represent a running stopwatch
#[derive(Debug, Clone, PartialEq, serde::Serialize, serde::Deserialize)]
pub struct StopWatch {